==> dde-printer_0.9.2.orig.tar.xz: dde-printer-0.9.2/src/Deamon/translations/dde-printer-helper_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="554"/>
        <source>URI and driver do not match.</source>
        <translation>الرابط URI و المشغل غير متوافقان.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="556"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>ثبت hplip أولا ثم أعد تشغيل البرنامج لتثبيت المشغل مجددا.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="564"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>الرجاء تعيين مشغل hplip ثم إعادة المحاولة.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="577"/>
        <source>URI can&apos;t be empty</source>
        <translation>الرابط URI لا يمكن أن يكون فارغ</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="584"/>
        <source> not found</source>
        <translation>غير موجود</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="307"/>
        <source>Check printer settings</source>
        <translation>تأكد من تعديلات الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="316"/>
        <source>Checking printer settings...</source>
        <translation>التأكد من تعديلات الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="319"/>
        <source>Success</source>
        <translation>تم بنجاح</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="329"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>لم يتم الحصول على خصائص الطابعة، الخطأ:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="337"/>
        <source>%1 is disabled</source>
        <translation>تم تعطيل %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="346"/>
        <source>is not accepting jobs</source>
        <translation>لا يقبل عمليات طبع</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="351"/>
        <source>Printer settings are ok</source>
        <translation>تعديلات الطابعة مناسبة</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="212"/>
        <source>Check printer connection</source>
        <translation>تأكد من ربط الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="224"/>
        <source>Checking printer connection...</source>
        <translation>التأكد من ربط الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="227"/>
        <source>Success</source>
        <translation>تم بنجاح</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="264"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>لا يمكن الإتصال بالطابعة، خطأ: 1%</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="272"/>
        <source> is not connected, URI: </source>
        <translation>غير متصل، الرابط URI:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="281"/>
        <source>%1 does not exist</source>
        <translation>%1 غير موجود</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="290"/>
        <source>Cannot connect to the printer</source>
        <translation>لا يمكن الإتصال بالطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="296"/>
        <source>The connection is valid</source>
        <translation>الإتصال مقبول</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="110"/>
        <source>Check CUPS server</source>
        <translation>تأكد من الخادم CUPS</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="116"/>
        <source>Checking CUPS server...</source>
        <translation>التأكد من الخادم CUPS...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="118"/>
        <source>CUPS server is invalid</source>
        <translation>الخادم CUPS غير مقبول</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="123"/>
        <source>CUPS server is valid</source>
        <translation>الخادم CUPS مقبول</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="141"/>
        <source>Checking driver...</source>
        <translation>التأكد من المشغل...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="144"/>
        <source>Success</source>
        <translation>تم بنجاح</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="152"/>
        <source>PPD file %1 not found</source>
        <translation>ملف PPD %1 غير موجود</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="162"/>
        <source>The driver is damaged</source>
        <translation>التعريف معطوب</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="178"/>
        <source>Driver filter %1 not found</source>
        <translation>لم يتم العثور على عامل تصفية محرك الأقراص %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="190"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 غير مثبت، لا يمكن الطبع حاليا</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="196"/>
        <source>Driver is valid</source>
        <translation>المشغل مقبول</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="202"/>
        <source>Check driver</source>
        <translation>تأكد من المشغل</translation>
    </message>
</context>
<context>
    <name>CupsMonitor</name>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="77"/>
        <source>Queuing</source>
        <translation>ترتيب</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="78"/>
        <source>Paused</source>
        <translation>توقف مؤقت</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="79"/>
        <source>Printing</source>
        <translation>طبع</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="80"/>
        <source>Stopped</source>
        <translation>متوقف</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="81"/>
        <source>Canceled</source>
        <translation>ملغى</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="82"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="83"/>
        <source>Completed</source>
        <translation>تمت العملية</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="338"/>
        <source>%1 timed out, reason: %2</source>
        <translation>إنتهى وقت %1، والسبب هو %2</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="352"/>
        <source>%1 printed successfully, please take away the paper in time!</source>
        <translation>تم طباعة %1 بنجاح، يرجى سحب الأوراق  المطبوعة في الوقت المحدد!</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="354"/>
        <source>%1 %2, reason: %3</source>
        <translation>%1 %2، السبب: 3%</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="906"/>
        <source>EveryWhere driver</source>
        <translation>ملف تعريف EveryWhere</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="371"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>لم يتم إيجاد حل لملف التعريف: 1%، خطأ: 2%</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="382"/>
        <source>The solution is invalid</source>
        <translation>الحل غير مقبول</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="252"/>
        <source>is invalid</source>
        <translation>غير مقبول</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="281"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>لم يتم تثبيت مشغل بالإتصال بالواجهة dbus</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="326"/>
        <source>Failed to install %1</source>
        <translation>فشل في تثبيت ٪ 1</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>غير موجود</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="372"/>
        <source>Check test page printing</source>
        <translation>تأكد من طبع الصفحة المسودة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="426"/>
        <source>Printing test page...</source>
        <translation>طبع الصفحة المسودة...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../Common/common.cpp" line="152"/>
        <source> not found, please ask the administrator for help</source>
        <translation>غير موجود ، الرجاء طلب المساعدة من المسؤول</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Print Manager</source>
        <translation>مدير الطباعة</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>إدارة الطباعة هي أداة إدارة الطابعة ، والتي تدعم إضافة وإزالة الطابعات ، وإدارة مهام الطباعة وما إلى ذلك.</translation>
    </message>
</context>
<context>
    <name>USBThread</name>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="257"/>
        <source>Configuring the printer %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="303"/>
        <source>Configuration successful. Click to view %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="307"/>
        <source>Configuration failed. Click to add the printer %1.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-printer_0.9.13.orig.tar.xz: dde-printer-0.9.13/src/Deamon/translations/dde-printer-helper_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="552"/>
        <source>URI and driver do not match.</source>
        <translation>الرابط URI و المشغل غير متوافقان.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="554"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>ثبت hplip أولا ثم أعد تشغيل البرنامج لتثبيت المشغل مجددا.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="562"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>الرجاء تعيين مشغل hplip ثم إعادة المحاولة.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="575"/>
        <source>URI can&apos;t be empty</source>
        <translation>الرابط URI لا يمكن أن يكون فارغ</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="582"/>
        <source> not found</source>
        <translation>غير موجود</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>تأكد من تعديلات الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>التأكد من تعديلات الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>تم بنجاح</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>لم يتم الحصول على خصائص الطابعة، الخطأ:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>تم تعطيل %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>لا يقبل عمليات طبع</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>تعديلات الطابعة مناسبة</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>تأكد من ربط الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>التأكد من ربط الطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>تم بنجاح</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>لا يمكن الإتصال بالطابعة، خطأ: 1%</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation>غير متصل، الرابط URI:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 غير موجود</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>لا يمكن الإتصال بالطابعة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>الإتصال مقبول</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>تأكد من الخادم CUPS</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>التأكد من الخادم CUPS...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>الخادم CUPS غير مقبول</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>الخادم CUPS مقبول</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>التأكد من المشغل...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>تم بنجاح</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>ملف PPD %1 غير موجود</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>التعريف معطوب</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>لم يتم العثور على عامل تصفية محرك الأقراص %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 غير مثبت، لا يمكن الطبع حاليا</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>المشغل مقبول</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>تأكد من المشغل</translation>
    </message>
</context>
<context>
    <name>CupsMonitor</name>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="77"/>
        <source>Queuing</source>
        <translation>ترتيب</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="78"/>
        <source>Paused</source>
        <translation>توقف مؤقت</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="79"/>
        <source>Printing</source>
        <translation>طبع</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="80"/>
        <source>Stopped</source>
        <translation>متوقف</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="81"/>
        <source>Canceled</source>
        <translation>ملغى</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="82"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="83"/>
        <source>Completed</source>
        <translation>تمت العملية</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="338"/>
        <source>%1 timed out, reason: %2</source>
        <translation>إنتهى وقت %1، والسبب هو %2</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="352"/>
        <source>%1 has been sent to the printer, please take away the paper in time!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="354"/>
        <source>%1 %2, reason: %3</source>
        <translation>%1 %2، السبب: 3%</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1022"/>
        <source>EveryWhere driver</source>
        <translation>ملف تعريف EveryWhere</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="372"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>لم يتم إيجاد حل لملف التعريف: 1%، خطأ: 2%</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="383"/>
        <source>The solution is invalid</source>
        <translation>الحل غير مقبول</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="250"/>
        <source>is invalid</source>
        <translation>غير مقبول</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="279"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>لم يتم تثبيت مشغل بالإتصال بالواجهة dbus</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="324"/>
        <source>Failed to install %1</source>
        <translation>فشل في تثبيت ٪ 1</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>غير موجود</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>تأكد من طبع الصفحة المسودة</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>طبع الصفحة المسودة...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source> not found, please ask the administrator for help</source>
        <translation>غير موجود ، الرجاء طلب المساعدة من المسؤول</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Print Manager</source>
        <translation>مدير الطباعة</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>إدارة الطباعة هي أداة إدارة الطابعة ، والتي تدعم إضافة وإزالة الطابعات ، وإدارة مهام الطباعة وما إلى ذلك.</translation>
    </message>
</context>
<context>
    <name>USBThread</name>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="256"/>
        <source>Configuring the printer %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="302"/>
        <source>Configuration successful. Click to view %1.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="306"/>
        <source>Configuration failed. Click to add the printer %1.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
